insert_image

Function insert_image 

pub fn insert_image(
    db_context: &DbContext,
    event_hub: &Arc<EventHub>,
    undo_redo_manager: &mut UndoRedoManager,
    position: i64,
    image_name: &str,
    width: i64,
    height: i64,
) -> Result<InsertImageResult>
Insert an image inline element at position using entity controllers.

Splits the text element at the insertion offset when needed.